@@ -93,15 +93,6 @@ class ViewGroupTests(TestCase):
         obj.add(va)
         self.assertRaises(TypeError, obj, None, None)
 
-    def test_call_exception_from_va(self):
-        obj = self._cut()
-        va = self._view_action(_failing_callable, 'this_view_group')
-        obj.add(va)
-        try:
-            obj(None, None)
-        except Exception, exc:
-            self.failUnless('this_view_group' in exc.args[0])
-
     def test_call_empty_output(self):
         obj = self._cut()
         va = self._view_action(_none_callable, 'this_view_group')
@@ -113,7 +104,7 @@ class ViewGroupTests(TestCase):
         obj.add(self._view_action(_dummy_callable, 'one'))
         obj.add(self._view_action(_dummy_callable, 'two'))
         self.assertEqual(obj.order, ['one', 'two'])
-        
+
     def test_set_order(self):
         obj = self._cut()
         obj.add(self._view_action(_dummy_callable, 'one'))
@@ -132,11 +123,10 @@ class ViewGroupTests(TestCase):
 
     def test_order_bad_key(self):
         obj = self._cut()
-        try:
-            obj.order = ['404']
-            self.fail("KeyError not raised")
-        except KeyError:
-            pass
+        obj.add(self._view_action(_name_callable, 'one'))
+        obj.add(self._view_action(_name_callable, 'two'))
+        obj.order = ['one', '404', 'two', 'none']
+        self.assertEqual(obj.order, ['one', 'two'])
 
     def test_set_order_with_some_keys_left_out(self):
         obj = self._cut()
@@ -182,6 +172,39 @@ class ViewGroupTests(TestCase):
         obj.order = ['three', 'one']
         self.assertEqual(obj.items(), [('three', va3), ('one', va1), ('two', va2)])
 
+    def test_priority_respected(self):
+        obj = self._cut()
+        va1 = self._view_action(_name_callable, 'one', priority = 1)
+        va2 = self._view_action(_name_callable, 'two', priority = 10)
+        va3 = self._view_action(_name_callable, 'three', priority = 5)
+        obj.add(va1)
+        obj.add(va2)
+        obj.add(va3)
+        self.assertEqual(obj.items(), [('one', va1), ('three', va3), ('two', va2)])
+        self.assertEqual(obj.order, ['one', 'three', 'two'])
+
+    def test_priority_equal_values(self):
+        obj = self._cut()
+        va1 = self._view_action(_name_callable, 'one', priority = 1)
+        va2 = self._view_action(_name_callable, 'two', priority = 2)
+        va3 = self._view_action(_name_callable, 'three', priority = 1)
+        obj.add(va1)
+        obj.add(va2)
+        obj.add(va3)
+        self.assertEqual(obj.items(), [('one', va1), ('three', va3), ('two', va2)])
+        self.assertEqual(obj.order, ['one', 'three', 'two'])
+
+    def test_priority_specified_mixed_with_no_value(self):
+        obj = self._cut()
+        va1 = self._view_action(_name_callable, 'one')
+        va2 = self._view_action(_name_callable, 'two', priority = 2)
+        va3 = self._view_action(_name_callable, 'three', priority = 1)
+        obj.add(va1)
+        obj.add(va2)
+        obj.add(va3)
+        self.assertEqual(obj.items(), [('three', va3), ('two', va2), ('one', va1)])
+        self.assertEqual(obj.order, ['three', 'two', 'one'])
+
 
 class ViewActionTests(TestCase):
     def setUp(self):
@@ -293,8 +316,7 @@ class RenderViewGroupTests(TestCase):
         context = testing.DummyResource()
         self.config.include("betahaus.viewcomponent.fixtures.dummy")
         res = self._fut(context, request, 'html')
-        expected = "{}, {}, <betahaus.viewcomponent.models.ViewAction 'stuff'>".format(
-            testing.DummyResource, testing.DummyRequest)
+        expected = "None, stuff"
         self.assertEqual(res, expected)
 
 
